<?php namespace Myriad\Installations\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

/**
 * @property string id
 * @property string uuid
 * @property string app_name
 * @property string app_version
 * @property string platform_name
 * @property string platform_version
 * @property string locale
 * @property string timezone
 * @property string push_type
 * @property string push_id
 * @property string user_agent
 * @property array custom
 * @property Carbon created_at
 * @property Carbon updated_at
 * @property Carbon deleted_at
 */
class Installation extends Model {

  use SoftDeletes;

  /**
   * The attributes that aren't mass assignable.
   *
   * @var array
   */
  protected $guarded = ['id', 'uuid', 'custom', 'created_at', 'updated_at', 'deleted_at'];

  /**
   * The attributes that should be hidden for arrays.
   *
   * @var array
   */
  protected $hidden = ['id', 'custom'];

  /**
   * The attributes that should be casted to native types.
   *
   * @var array
   */
  protected $casts = [
    'custom' => 'json',
  ];

  /**
   * Get the table associated with the model.
   *
   * @return string
   */
  public function getTable() {
    return config('installations.table_name', 'installations');
  }

  /**
   * Put a key value pair to custom
   *
   * @param $key
   * @param $value
   */
  public function putCustom($key, $value) {
    $this->custom = array_merge(is_array($this->custom) ? $this->custom : [], [$key => $value]);
  }

  /**
   * Get a value from custom that was set with putCustom
   *
   * @param $key
   * @param $default
   * @return mixed
   */
  public function getCustom($key, $default) {
    $custom = $this->custom;
    if (!is_array($custom)) {
      return $default;
    }
    return array_key_exists($custom, $key) ? $custom[$key] : $default;
  }

}