<?php namespace Myriad\Installations\Validation;

use Myriad\Installations\Exceptions\InstallationValidationException;

interface IInstallationValidationProvider {
  /**
   * Get the rules used to validate an installation.
   *
   * @param array $attributes
   * @return array
   */
  public function getRules($attributes = []);

  /**
   * Get custom messages
   *
   * @param array $attributes
   * @return array
   */
  public function getMessages($attributes = []);

  /**
   * Get a validator for the given attributes
   *
   * @param $attributes
   * @return \Illuminate\Contracts\Validation\Validator
   */
  public function getValidator($attributes);

  /**
   * Validate a uuid
   *
   * @param $uuid
   * @return true
   * @throws InstallationValidationException
   */
  public function validateUUID($uuid);

  /**
   * Normalize a uuid to string
   *
   * @param $uuid
   * @return string
   */
  public function normalizeUUID($uuid);

}